@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-VERSION = '0.7.2' # (major.minor.sub-minor)
+VERSION = '0.7.5' # (major.minor.sub-minor)
 
 # Minor version changes each time database schema changes 
 # See CHANGELOG.md for detailed change history
@@ -39,10 +39,6 @@ import sqlite3
 import sys
 import time
 
-# GStreamer for playing audio
-import pygst
-pygst.require('0.10')
-import gst
 
 # Get path to determine library and static resource locations
 running_path = sys.path[0]
@@ -1522,7 +1518,7 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
             gobject.timeout_add_seconds(TIMER_TIMEOUT_INTERVAL_SECS, self.timer_countdown)
             self.show_info_banner(self.top_win, _('Timer Started'))
 
-        # Why doesn't this work? Start/Stop button doesn't redraw when clicked
+        # Redraw the Start/Stop Timer button
         self.timer_start_stop_btn.remove(self.timer_start_stop_btn_hbox)
         self.timer_start_stop_btn_hbox = self.get_timer_start_stop_btn_hbox()
         self.timer_start_stop_btn.add(self.timer_start_stop_btn_hbox)
@@ -1537,7 +1533,7 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
 
 
     def timer_countdown(self):
-        if not 'running' in self.timer:
+        if not self.timer or not 'running' in self.timer:
             return False
 
         # Timer is running but still has time to go
@@ -1552,9 +1548,7 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
         else:
             self.set_timer_adjustment_value(0)
             self.on_timer_start_or_stop()
-            pl = gst.element_factory_make("playbin", "player")
-            pl.set_property('uri','file:///usr/share/sounds/ui-wake_up_tune.wav')
-            pl.set_state(gst.STATE_PLAYING)
+            os.system('aplay /usr/share/sounds/ui-wake_up_tune.wav')
             return False
 
 
@@ -1562,7 +1556,9 @@ etc. of all habits, whereas the daily habits view only shows habits for the curr
         # Clear data structures and widgets
         if 'running' in self.timer:
             self.show_info_banner(self.top_win, _('Timer Cleared'))
-            self.timer = {}
+
+        # Clear the timer so that idle timeouts terminate immediately on next cycle
+        self.timer = {}
 
 
 
